#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var fs_1 = tslib_1.__importDefault(require("fs"));
var path_1 = tslib_1.__importDefault(require("path"));
var minimist_1 = tslib_1.__importDefault(require("minimist"));
var colors_1 = tslib_1.__importDefault(require("colors"));
var fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
var maps_1 = tslib_1.__importDefault(require("./maps"));
var runShell_1 = require("./libraries/runShell");
var getRnVersion_1 = require("./libraries/getRnVersion");
var replacePlaceholder_1 = require("./libraries/replacePlaceholder");
var copyTemplateFile_1 = require("./libraries/copyTemplateFile");
var createDir_1 = require("./libraries/createDir");
var installPackage_1 = require("./libraries/installPackage");
var getYarnVersion_1 = require("./libraries/getYarnVersion");
var wrapQuots_1 = require("./libraries/wrapQuots");
var args = minimist_1.default(process.argv.slice(2));
if (args._.length === 0) {
    console.log([
        '',
        colors_1.default.green('  Usage: react-native-init ProjectName [--npm]'),
        '',
    ].join('\n'));
    process.exit(1);
}
var projectName = args._[0];
var projectPath = path_1.default.resolve(projectName);
if (fs_1.default.existsSync(projectPath)) {
    console.error(colors_1.default.red("Directory " + projectName + " already exists."));
    process.exit(1);
}
console.log("Fetching latest react-native version between " + maps_1.default.minRnVersion + " and " + maps_1.default.maxRnVersion + "...");
var rnVersion = getRnVersion_1.getRnVersion();
if (!rnVersion) {
    console.log(colors_1.default.red('Unknown react-native version.'));
    process.exit(1);
}
var bin = path_1.default.resolve(__dirname, '../node_modules/.bin/react-native');
var installCommand = bin + " init " + projectName + " --version=" + rnVersion;
if (args.npm) {
    installCommand += ' --npm';
}
runShell_1.runShell(installCommand);
process.chdir(projectPath);
(function () {
    var packageFilePath = path_1.default.resolve('package.json');
    var packageData = require(packageFilePath);
    if (!packageData.scripts) {
        packageData.scripts = {};
    }
    packageData.scripts.start = 'node scripts/start --port=8081';
    packageData.license = packageData.license || 'UNLICENSED';
    fs_1.default.writeFileSync(packageFilePath, JSON.stringify(packageData, null, 2));
})();
replacePlaceholder_1.replacePlaceholder('android/gradle.properties', [
    {
        pattern: /#\s*(org\.gradle\.jvmargs\s*=.+)/,
        value: '$1',
    }
]);
createDir_1.createDir('scripts');
copyTemplateFile_1.copyTemplateFile('.editorconfig');
copyTemplateFile_1.copyTemplateFile('README.md');
fs_extra_1.default.copySync(path_1.default.join(__dirname, '../templates/scripts'), path_1.default.resolve('scripts'));
runShell_1.runShellAndReturn('echo start.command >> .gitignore');
replacePlaceholder_1.replacePlaceholder('scripts/init/index.js', [
    {
        pattern: /:install_tool:/g,
        value: getYarnVersion_1.getYarnVersion() ? 'yarn' : 'npm',
    },
    {
        pattern: /:minJdkVersion:/g,
        value: maps_1.default.minJdkVersion,
    },
    {
        pattern: /:maxJdkVersion:/g,
        value: maps_1.default.maxJdkVersion,
    },
    {
        pattern: /:minNodeVersion:/g,
        value: maps_1.default.minNodeVersion,
    },
    {
        pattern: /:maxNodeVersion:/g,
        value: maps_1.default.maxNodeVersion,
    },
    {
        pattern: /:minXcodeVersion:/g,
        value: maps_1.default.minXcodeVersion,
    },
    {
        pattern: /:maxXcodeVersion:/g,
        value: maps_1.default.maxXcodeVersion,
    },
]);
replacePlaceholder_1.replacePlaceholder('README.md', [
    {
        pattern: /:install_tool:/g,
        value: getYarnVersion_1.getYarnVersion() ? 'yarn' : 'npm',
    },
]);
replacePlaceholder_1.replacePlaceholder('scripts/init/sdkManager.sh', [
    {
        pattern: /:sdk_packages:/g,
        value: wrapQuots_1.wrapQuots(maps_1.default.androidSdkPackages),
    },
    {
        pattern: /:sdk_manager_code:/g,
        value: maps_1.default.androidSdkManagerCode,
    },
]);
replacePlaceholder_1.replacePlaceholder('scripts/start/createEmulator.sh', [
    {
        pattern: /:rn_version:/g,
        value: rnVersion.split('.').join(''),
    },
    {
        pattern: /:avd_package:/g,
        value: wrapQuots_1.wrapQuots(maps_1.default.androidAvd),
    }
]);
replacePlaceholder_1.replacePlaceholder('scripts/build/archive.sh', [
    {
        pattern: /:project_name:/g,
        value: projectName,
    }
]);
replacePlaceholder_1.replacePlaceholder('scripts/build/android-signature.sh', [
    {
        pattern: /:project_name:/g,
        value: projectName,
    }
]);
installPackage_1.installPackage([
    'ajv',
    'eslint',
    '@types/react-native',
    '@types/react',
    'compare-versions',
    'colors',
    'minimist',
], true);
console.log([
    '',
    colors_1.default.green("New project '" + projectName + "' is created. Open project and read file README.md"),
    '',
    colors_1.default.green("New Project path: " + projectPath),
    '',
].join('\n'));
